@@ -836,7 +836,7 @@ static int backtrace(void) {
 	   "EOF");
   int retval = system(cmd);
   snprintf(cmd, sizeof(cmd), 
-	   "gdb -batch -x gdb_commands --pid %i --readnow  >> recipe.backtrace 2> /dev/null", 
+	   "gdb -batch -x gdb_commands --pid %i --readnow  >> recipe.backtrace-unprocessed 2> /dev/null", 
 	   (int)getpid());
   retval |= system(cmd);
   unlink("gdb_commands");
@@ -844,21 +844,23 @@ static int backtrace(void) {
   
 }
 
+#ifdef HAVE_MCHECK
 static void mcheck_handler(enum mcheck_status status) {
   char cmd[100];
   snprintf(cmd, sizeof(cmd), 
-	   "echo Memory corruption > recipe.backtrace");
+	   "echo Memory corruption > recipe.backtrace-unprocessed");
   int retval = system(cmd);
   if (retval == 0) {
       backtrace();
   }
   abort();
 }
+#endif
 
 static int segv_handler(int sig) {
   char cmd[100];
   snprintf(cmd, sizeof(cmd), 
-	   "echo Received signal: %i > recipe.backtrace", sig);
+	   "echo Received signal: %i > recipe.backtrace-unprocessed", sig);
   int retval = system(cmd);
   backtrace();
 
@@ -883,6 +885,8 @@ static void setup_tracing(CPL_recipe *self) {
     mcheck(mcheck_handler);
 #endif
 
+    typedef void (*sighandler_t)(int);
+
     signal(SIGSEGV, (sighandler_t) segv_handler);
     signal(SIGINT, (sighandler_t) segv_handler);
     signal(SIGHUP, (sighandler_t) segv_handler);
@@ -970,7 +974,7 @@ CPL_recipe_exec(CPL_recipe *self, PyObject *args) {
 					  retval, &clock_end);
 	long n_bytes = write(fd[1], ptr, ((long *)ptr)[0]);
 	close(fd[1]);
-	exit(n_bytes != ((long *)ptr)[0]);
+	_exit(n_bytes != ((long *)ptr)[0]);
     }
     
     close(fd[1]);
