@@ -361,7 +361,10 @@ class Recipe(object):
             logger = LogServer(os.path.join(output_dir, 'log'), logname,
                                loglevel)
         except:
-            self._cleanup(output_dir, logger, delete)
+            try:
+                self._cleanup(output_dir, logger, delete)
+            except:
+                pass
             raise
         if not threaded:
             return self._exec(output_dir, parlist, framelist, input_len, 
@@ -412,14 +415,18 @@ class Recipe(object):
 
     def _cleanup(self, output_dir, logger, delete):
         try:
-            bt = os.path.join(output_dir, 'recipe.backtrace')
+            bt = os.path.join(output_dir, 'recipe.backtrace-unprocessed')
             if os.path.exists(bt):
                 with file(bt) as bt_file:
-                    raise RecipeCrash(bt_file)
+                    os.rename(bt, os.path.join(output_dir, 'recipe.backtrace'))
+                    ex = RecipeCrash(bt_file)
+                    ex.log(logger.logger)
+                    raise ex
+
         finally:
             if delete:
                 shutil.rmtree(output_dir)
-            else:
+            elif logger:
                 os.remove(logger.logfile)
 
     @property
